ICM20948 9-DOF Accelerometer, Magnetometer and Gyroscope
========================================================

|Build Status| |Coverage Status| |PyPi Package| |Python Versions|

Installing
==========

Stable library from PyPi:

-  Just run ``sudo pip install icm20948``

Latest/development library from GitHub:

-  ``git clone https://github.com/pimoroni/icm20948-python``
-  ``cd icm20948-python``
-  ``sudo ./install.sh``

.. |Build Status| image:: https://travis-ci.com/pimoroni/icm20948-python.svg?branch=master
   :target: https://travis-ci.com/pimoroni/icm20948-python
.. |Coverage Status| image:: https://coveralls.io/repos/github/pimoroni/icm20948-python/badge.svg?branch=master
   :target: https://coveralls.io/github/pimoroni/icm20948-python?branch=master
.. |PyPi Package| image:: https://img.shields.io/pypi/v/icm20948.svg
   :target: https://pypi.python.org/pypi/icm20948
.. |Python Versions| image:: https://img.shields.io/pypi/pyversions/icm20948.svg
   :target: https://pypi.python.org/pypi/icm20948
